/*
 * © 2009 David ‘Bombe’ Roden
 */
package net.pterodactylus.arachne.core;

import de.ina.util.validation.Validation;

/**
 * Container for a freenet site. A freenet site consists of the routing and
 * decryption keys and the basename, without the edition.
 *
 * @author David ‘Bombe’ Roden <bombe@pterodactylus.net>
 */
public class Site {

	/** The key of the site. */
	private final String key;

	/** The basename of the site. */
	private final String basename;

	/**
	 * Creates a new site with the given key and basename.
	 *
	 * @param key
	 *            The key of the site
	 * @param basename
	 *            The basename of the site
	 */
	public Site(String key, String basename) {
		Validation.begin().isNotNull("key", (Object) key).isNotNull("basename", (Object) basename).check();
		this.key = key;
		this.basename = basename;
	}

	/**
	 * The routing and decryption keys of the site.
	 *
	 * @return The site’s routing and decryption keys
	 */
	public String getKey() {
		return key;
	}

	/**
	 * Returns the basename of the site, without the edition number.
	 *
	 * @return The site’s basename
	 */
	public String getBasename() {
		return basename;
	}

	//
	// OBJECT METHODS
	//

	/**
	 * {@inheritdoc}
	 *
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return getClass().getName() + "[key=" + key + ",basename=" + basename + "]";
	}

}
